==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-nl_NL-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Bedrijf contactgegevens"

, "Organisation / Unit"
: "Bedrijf / afdeling"

, "Business Address"
: "Bedrijfsadres"

, "Email"
: "Email"

, "Telephone Work"
: "Telefoon werk"

, "Telephone Cellphone"
: "Mobiel"

, "Telephone Car"
: "Auto telefoon"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Buzzer nummer"

, "URL"
: "Url"

, "Role"
: "Functie"

, "Room"
: "Kamer"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent telefoonnummer"

, "Private Contact Data"
: "Prive contactgegevens"

, "Private Address"
: "Prive adres"

, "Email Home"
: "Email thuis"

, "Telephone Home"
: "Telefoon thuis"

, "Telephone Cellphone Private"
: "Prive mobielenummer"

, "Telephone Fax Home"
: "Fax thuis"

, "URL Home"
: "Url thuis"

, "Other Data"
: "Andere gegevens"

, "Birthday"
: "Geboortedatum"

, "Job Title"
: "Titel werk"

, "Dear Mister"
: "Geachte Heer"

, "Dear Miss"
: "Geachte Mevrouw"

, "Dear"
: "Beste"

, "Mister"
: "Meneer"

, "Misses"
: "Mevrouw"

, "%s's personal addressbook"
: "%s's persoonlijke adresboek"

, "Lists"
: "Lijsten"

, "List Roles"
: ""

, "manage shared addressbooks"
: "beheer gedeelde adresboeken"

, "Create new shared addressbook folders"
: "Maak nieuwe gedeelde adresboek folders"

, "manage shared addressbook favorites"
: "beheer gedeelde adresboek favorieten"

, "Create or update shared addressbook favorites"
: "controleer of update gedeelde adresboek favorieten"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: "CardDAV URL"

, "Contact, Contacts"
: [
  "Contact"
 ,"Contacten"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: "Map"

, "Personal Information"
: "Persoonlijke informatie"

, "Salutation"
: "Begroeting"

, "Title"
: "Titel"

, "First Name"
: "Voornaam"

, "Middle Name"
: "Tussenvoegsel"

, "Last Name"
: "Achternaam"

, "Company"
: "Bedrijf"

, "Unit"
: "Afdeling"

, "Suffix"
: "Achtervoegsel"

, "Job Role"
: "Functie"

, "Display Name"
: "Weergavenaam"

, "Contact Information"
: "Contact informatie"

, "Phone"
: "Telefoon"

, "Mobile"
: "Mobiel"

, "Fax"
: "Fax (prive)"

, "Phone (private)"
: "Telefoon (prive)"

, "Mobile (private)"
: "Mobiel (prive)"

, "Fax (private)"
: "Fax (prive)"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "E-mail (prive)"

, "Web"
: "Web"

, "Company Address"
: "Bedrijfsadres"

, "Street"
: "Straat"

, "Street 2"
: "Straat 2"

, "Region"
: "Provincie"

, "Postal Code"
: "Postcode"

, "City"
: "Plaats"

, "Country"
: "Land"

, "Description"
: "Omschrijving"

, "Enter description"
: "Voer omschrijving in"

, "Export as pdf"
: "Exporteer als pdf"

, "Parse address"
: "ontleden adres"

, "Paste address"
: "Plak adres"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Plak een adres of een URI naar een Vcard dat verwerkt moet worden:"

, "Failed to parse address!"
: "Adres verwerken mislukt!"

, "The address could not be read."
: "Het adres kon niet gelezen worden"

, "End token mode"
: "Einde token mode"

, "New Contact"
: "Nieuw contact"

, "Addressbook, Addressbooks"
: [
  "Adresboek"
 ,"Adresboeken"

]
, "ID"
: ""

, "Name"
: "Naam"

, "Member of List"
: "Lid van lijst"

, "Street (Company Address)"
: "Straat (Bedrijfsadres)"

, "Street 2 (Company Address)"
: "Straat 2 (Bedrijfsadres)"

, "City (Company Address)"
: "Stad (Bedrijfsadres)"

, "Region (Company Address)"
: "Provincie (Bedrijfsadres)"

, "Postal Code (Company Address)"
: "Postcode (Bedrijfsadres)"

, "Country (Company Address)"
: "Land (Bedrijfsadres)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Straat (Prive adres)"

, "Street 2 (Private Address)"
: "Straat 2 (Prive adres)"

, "City (Private Address)"
: "Stad (Prive adres)"

, "Region (Private Address)"
: "Provincie (Prive adres)"

, "Postal Code (Private Address)"
: "Postcode (Prive adres)"

, "Country (Private Address)"
: "Land (Prive adres)"

, "Company Communication"
: "Bedrijfs communicatie"

, "Private Communication"
: "Prive communicatie"

, "Web (private)"
: "Web (prive)"

, "Contacts"
: "Contacten"

, "Addressbooks"
: "Adresboeken"

, "User Account"
: "Gebruikersaccount"

, "Quick Search"
: "Snel zoeken"

, "Type"
: "Type"

, "Last Modified Time"
: "Laast aangepast"

, "Last Modified By"
: "Laatst aangepast door"

, "Creation Time"
: "Aanmaaktijd"

, "Created By"
: "Gemaakt door"

, "List, Lists"
: [
  "Lijst"
 ,"Lijsten"

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: "Bedrijfsadres"

, "Private address"
: "Prive adres"

, "Select contact"
: "Selecteer contact"

, "Private"
: "Prive"

, "Info"
: "Info"

, "Insecure link"
: "Onveilige link"

, "Please review this link in edit dialog."
: "Lees deze koppeling in bewerken dialoogvenster."

, "Export {0}, Export {0}"
: [
  "Exporteer"
 ,"Exporteren"

]
, "Export as PDF"
: "Exporteer als PDF"

, "Export as CSV"
: "Exporteer als CSV"

, "Export as ODS"
: "Exporteer als ODS"

, "Export as XLS"
: "Exporteer als XLS"

, "Export as DOC"
: "Exporteer als DOC"

, "Export as ..."
: "Exporteer als ..."

, "Import contacts"
: "Importeer contacten"

, "Contact of a user account"
: "Contact van gebruikersaccount"

, "No name"
: ""

, "Tags"
: "Labels"

, "Full Name"
: "Volledige naam"

, "Postalcode"
: "Postcode"

, "Street (private)"
: "Straat (prive)"

, "City (private)"
: "Plaats (prive)"

, "Region (private)"
: "Provincie (prive)"

, "Postalcode (private)"
: "Postcode (prive)"

, "Country (private)"
: "Land (prive)"

, "Car phone"
: "Auto telefoon"

, "Pager"
: "Buzzer"

, "Email (private)"
: "Email (prive)"

, "URL (private)"
: "Url (prive)"

, "Note"
: "Notitie"

, "Timezone"
: "Tijdzone"

, "Geo"
: "Geo"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: "Nieuw contact afbeelding geupload"

, "All contacts"
: "Alle contacten"

, "Default Addressbook"
: "Standaard adresboek"

, "The default addressbook for new contacts"
: "Standaard adresboek voor nieuwe contacten"

, "Default Favorite"
: "Standaard favoriet"

, "The default favorite which is loaded on addressbook startup"
: "Standaard favoriet bij opstarten adresboek"

, "Contacts ODS export configuration"
: "Contacten ODS export configuratie"

, "Use this configuration for the contact ODS export."
: "Gebruik deze configuratie voor de contactpersoon ODS export."

, "Contacts XLS export configuration"
: "Contacten XLS export configuratie"

, "Use this configuration for the contact XLS export."
: "Gebruik deze configuratie voor de contactpersoon XLS export."

, "default"
: "standaard"

, "This contact has been automatically added by the system as an event attender"
: "Dit contact is automatisch toegevoegd door het systeem als een gebeurtenis genodigde "

, "All Contacts"
: "Alle contacten"

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: "Contact controle velden"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Deze velden worden gecontroleerd wanneer er een nieuw contact wordt gemaakt. Indien een veld met dezelfde gegevens is gevonden, wordt een veld geduplideerd."

, "Contact salutations available"
: "Contacteer begroetingen beschikbaar"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mogelijke contact begroetingen. Houd er rekening mee dat er extra waarden een invloed kunnen hebben op andere Adresboek systemen op de uitvoer en synchronisatie."

, "Mr"
: "Mr"

, "Ms"
: "Mvr"

, "Parsing rules for addresses"
: "parsingregels voor adressen"

, "Path to a XML file with address parsing rules."
: "Pad naar een XML-bestand met adres parsingregels."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Nederlands"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lijst(###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Geïmporteerd op ###CURRENTDATE### op ###CURRENTTIME### door ###USERFULLNAME###"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Contact CSV importeren uit Outlook adresboek"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Contact importeren van Google adresboek"

, "Contact CSV import from mac address book"
: "Contact CSV importeren van Apple adresboek"

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Contact VCARD importeren"

, "Internal Contacts"
: "Interne contacten"

, "All contacts I have read grants for"
: "Alle contacten waar ik toestemming voor heb"

, "My company"
: "Mijn bedrijf"

, "All coworkers in my company"
: "Alle medewerkers in mijn bedrijf"

, "My contacts"
: "Mijn contacten"

, "All contacts in my Addressbooks"
: "Alle contacten in mijn adresboek"

, "Last modified by me"
: "Laatst aangepast door mij"

, "All contacts that I have last modified"
: "Alle contacten die ik heb aangepast"

, "Contact"
: "Contact"

, "List Role"
: ""

, "Addressbook"
: "Adresboek"

, "List"
: "Lijst"

, "Email Address"
: ""

, "Export {0}"
: "Exporteer"

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Bedrijf contactgegevens"

, "Organisation / Unit"
: "Bedrijf / afdeling"

, "Business Address"
: "Bedrijfsadres"

, "Email"
: "Email"

, "Telephone Work"
: "Telefoon werk"

, "Telephone Cellphone"
: "Mobiel"

, "Telephone Car"
: "Auto telefoon"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Buzzer nummer"

, "URL"
: "Url"

, "Role"
: "Functie"

, "Room"
: "Kamer"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent telefoonnummer"

, "Private Contact Data"
: "Prive contactgegevens"

, "Private Address"
: "Prive adres"

, "Email Home"
: "Email thuis"

, "Telephone Home"
: "Telefoon thuis"

, "Telephone Cellphone Private"
: "Prive mobielenummer"

, "Telephone Fax Home"
: "Fax thuis"

, "URL Home"
: "Url thuis"

, "Other Data"
: "Andere gegevens"

, "Birthday"
: "Geboortedatum"

, "Job Title"
: "Titel werk"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lijst"
 ,"Lijsten"

]
, "Percent"
: ""

, "Description"
: "Omschrijving"

, "Members"
: ""

, "Type"
: "Type"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Adresboek"
 ,"Adresboeken"

]
, "Contact, Contacts"
: [
  "Contact"
 ,"Contacten"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Land"

, "City"
: "Plaats"

, "Postalcode"
: "Postcode"

, "Region"
: "Provincie"

, "Street"
: "Straat"

, "Street 2"
: "Straat 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Land (prive)"

, "City (private)"
: "Plaats (prive)"

, "Postalcode (private)"
: "Postcode (prive)"

, "Region (private)"
: "Provincie (prive)"

, "Street (private)"
: "Straat (prive)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (prive)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Notitie"

, "Last Name"
: "Achternaam"

, "Display Name"
: "Weergavenaam"

, "Full Name"
: "Volledige naam"

, "First Name"
: "Voornaam"

, "Middle Name"
: "Tussenvoegsel"

, "Title"
: "Titel"

, "Suffix"
: "Achtervoegsel"

, "Company"
: "Bedrijf"

, "Unit"
: "Afdeling"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Functie"

, "Salutation"
: "Begroeting"

, "syncBackendIds"
: ""

, "Car phone"
: "Auto telefoon"

, "Mobile"
: "Mobiel"

, "Mobile (private)"
: "Mobiel (prive)"

, "Fax"
: "Fax (prive)"

, "Fax (private)"
: "Fax (prive)"

, "Phone (private)"
: "Telefoon (prive)"

, "Pager"
: "Buzzer"

, "Phone"
: "Telefoon"

, "Timezone"
: "Tijdzone"

, "Web"
: "Web"

, "URL (private)"
: "Url (prive)"

, "Label"
: ""

, "Lists"
: "Lijsten"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Contact informatie"

, "Company Address"
: "Bedrijfsadres"

, "New Contact"
: "Nieuw contact"

, "ID"
: ""

, "Name"
: "Naam"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importeer contacten"

, "Contact of a user account"
: "Contact van gebruikersaccount"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Prive"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Labels"

, "List Roles"
: ""

, "Street (Company Address)"
: "Straat (Bedrijfsadres)"

, "Street 2 (Company Address)"
: "Straat 2 (Bedrijfsadres)"

, "City (Company Address)"
: "Stad (Bedrijfsadres)"

, "Region (Company Address)"
: "Provincie (Bedrijfsadres)"

, "Postal Code (Company Address)"
: "Postcode (Bedrijfsadres)"

, "Country (Company Address)"
: "Land (Bedrijfsadres)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Straat (Prive adres)"

, "Street 2 (Private Address)"
: "Straat 2 (Prive adres)"

, "City (Private Address)"
: "Stad (Prive adres)"

, "Region (Private Address)"
: "Provincie (Prive adres)"

, "Postal Code (Private Address)"
: "Postcode (Prive adres)"

, "Country (Private Address)"
: "Land (Prive adres)"

, "Company Communication"
: "Bedrijfs communicatie"

, "Private Communication"
: "Prive communicatie"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "E-mail (prive)"

, "Web (private)"
: "Web (prive)"

, "Contacts"
: "Contacten"

, "Addressbooks"
: "Adresboeken"

, "User Account"
: "Gebruikersaccount"

, "Quick Search"
: "Snel zoeken"

, "Postal Code"
: "Postcode"

, "Last Modified Time"
: "Laast aangepast"

, "Last Modified By"
: "Laatst aangepast door"

, "Creation Time"
: "Aanmaaktijd"

, "Created By"
: "Gemaakt door"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Voer omschrijving in"

, "{0} must be given"
: ""

, "Member of List"
: "Lid van lijst"

, "Map"
: "Map"

, "Company address"
: "Bedrijfsadres"

, "Private address"
: "Prive adres"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Persoonlijke informatie"

, "Parse address"
: "ontleden adres"

, "Print contact"
: ""

, "Paste address"
: "Plak adres"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Plak een adres of een URI naar een Vcard dat verwerkt moet worden:"

, "Failed to parse address!"
: "Adres verwerken mislukt!"

, "The address could not be read."
: "Het adres kon niet gelezen worden"

, "End token mode"
: "Einde token mode"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Alle contacten"

, "Default Addressbook"
: "Standaard adresboek"

, "The default addressbook for new contacts"
: "Standaard adresboek voor nieuwe contacten"

, "Default Favorite"
: "Standaard favoriet"

, "The default favorite which is loaded on addressbook startup"
: "Standaard favoriet bij opstarten adresboek"

, "Contacts ODS export configuration"
: "Contacten ODS export configuratie"

, "Use this configuration for the contact ODS export."
: "Gebruik deze configuratie voor de contactpersoon ODS export."

, "Contacts XLS export configuration"
: "Contacten XLS export configuratie"

, "Use this configuration for the contact XLS export."
: "Gebruik deze configuratie voor de contactpersoon XLS export."

, "default"
: "standaard"

, "All Contacts"
: "Alle contacten"

, "This contact has been automatically added by the system as an event attender"
: "Dit contact is automatisch toegevoegd door het systeem als een gebeurtenis genodigde "

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Contact controle velden"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Deze velden worden gecontroleerd wanneer er een nieuw contact wordt gemaakt. Indien een veld met dezelfde gegevens is gevonden, wordt een veld geduplideerd."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Contacteer begroetingen beschikbaar"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mogelijke contact begroetingen. Houd er rekening mee dat er extra waarden een invloed kunnen hebben op andere Adresboek systemen op de uitvoer en synchronisatie."

, "Mr"
: "Mr"

, "Ms"
: "Mvr"

, "Parsing rules for addresses"
: "parsingregels voor adressen"

, "Path to a XML file with address parsing rules."
: "Pad naar een XML-bestand met adres parsingregels."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Contact VCARD importeren"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lijst(###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Geïmporteerd op ###CURRENTDATE### op ###CURRENTTIME### door ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Nederlands"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Contact CSV importeren uit Outlook adresboek"

, "Contact CSV import from mac address book"
: "Contact CSV importeren van Apple adresboek"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Contact importeren van Google adresboek"

, "manage shared addressbooks"
: "beheer gedeelde adresboeken"

, "Create new shared addressbook folders"
: "Maak nieuwe gedeelde adresboek folders"

, "manage shared addressbook favorites"
: "beheer gedeelde adresboek favorieten"

, "Create or update shared addressbook favorites"
: "controleer of update gedeelde adresboek favorieten"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's persoonlijke adresboek"

, "All contacts I have read grants for"
: "Alle contacten waar ik toestemming voor heb"

, "My company"
: "Mijn bedrijf"

, "All coworkers in my company"
: "Alle medewerkers in mijn bedrijf"

, "My contacts"
: "Mijn contacten"

, "All contacts in my Addressbooks"
: "Alle contacten in mijn adresboek"

, "Last modified by me"
: "Laatst aangepast door mij"

, "All contacts that I have last modified"
: "Alle contacten die ik heb aangepast"

, "Internal Contacts"
: "Interne contacten"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Dutch\nX-Poedit-Country: NETHERLANDS\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: "Lijst"

, "Addressbook"
: "Adresboek"

, "Contact"
: "Contact"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
